@@ -8,10 +8,13 @@ public enum ModelParam {
 	use_mlock, //
 	;
 
-	/** System property to set the default number of layers offloaded to GPU. */
-	final static String SYSTEM_PROPERTY_MODEL_PARAM_PREFIX = "jjml.llama.model.";
+	/**
+	 * System property to set model parameters, such as the default number of layers
+	 * offloaded to GPU.
+	 */
+	final static String SYSTEM_PROPERTY_MODEL_PARAM_PREFIX = "jjml.llm.model.";
 
-	/** As a system property used to override default value.*/
+	/** As a system property used to override default value. */
 	public String asSystemProperty() {
 		return SYSTEM_PROPERTY_MODEL_PARAM_PREFIX + name();
 	}
